<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>LayerCompatibility</name>
    <message>
        <location filename="../LayerCompatibility.js" line="+30"/>
        <source>Layer</source>
        <translation>Laag</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Compatibility</source>
        <translation>Compatibiliteit</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Layer 0</source>
        <translation>Laag 0</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Layer 0 behaves like a regular layer (QCAD)</source>
        <translation>Laag 0 gedraagt zich als een gewone laag (QCAD)</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Layer 0 behaves differently (best compatibility)</source>
        <translation>Laag 0 gedraagt zich anders (beste compatibiliteit)</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Entities in blocks on layer 0 take on attributes and visibility of block reference.</source>
        <translation>Objecten in blokken op laag 0 nemen attributen en zichtbaarheid van blok referentie aan.</translation>
    </message>
    <message>
        <source>Entities in blocks on layer 0 take on attributes of block reference (compatibility)</source>
        <translation type="vanished">Objecten in blokken op laag 0 nemen attributen van blok referentie aan (compatibiliteit)</translation>
    </message>
</context>
</TS>
